@@ -1,4 +1,4 @@
-// Copyright (C) 2021-2024 Joel Rosdahl and other contributors
+// Copyright (C) 2021-2025 Joel Rosdahl and other contributors
 //
 // See doc/AUTHORS.adoc for a complete list of contributors.
 //
@@ -140,12 +140,6 @@ TEST_CASE("util::make_relative_path")
     CHECK(make_relative_path(actual_cwd, apparent_cwd, apparent_cwd + "/x")
           == "x");
   }
-
-  SUBCASE("Match if using resolved (using realpath(3)) path")
-  {
-    CHECK(make_relative_path(actual_cwd, actual_cwd, apparent_cwd + "/x")
-          == "x");
-  }
 #endif
 }
 
